@@ -6,8 +6,8 @@ use anchor_client::anchor_lang::{
     },
     InstructionData,
 };
-use cronos_program::pda::PDA;
 use cronos_program::state::InstructionData as CronosInstructionData;
+use cronos_program::{pda::PDA, state::TaskSchedule};
 
 pub fn task_create(
     task_pda: PDA,
@@ -15,9 +15,7 @@ pub fn task_create(
     daemon: Pubkey,
     owner: Pubkey,
     ix: Instruction,
-    exec_at: i64,
-    stop_at: i64,
-    recurr: i64,
+    schedule: TaskSchedule,
 ) -> Instruction {
     Instruction {
         program_id: cronos_program::ID,
@@ -31,9 +29,7 @@ pub fn task_create(
         ],
         data: cronos_program::instruction::TaskCreate {
             ix: CronosInstructionData::from(ix),
-            exec_at,
-            stop_at,
-            recurr,
+            schedule,
             bump: task_pda.1,
         }
         .data(),
